==> libavg_1.5.4.orig.tar.gz: libavg-1.5.4/src/anim/WaitAnim.h <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2008 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#ifndef _WaitAnim_H_
#define _WaitAnim_H_

#include "../api.h"

#include "SimpleAnim.h"

namespace avg {

class AVG_API WaitAnim: public Anim {
public:
    virtual ~WaitAnim();
   
    static AnimPtr create(long long duration = -1,
            const boost::python::object& startCallback=boost::python::object(), 
            const boost::python::object& stopCallback=boost::python::object());

    virtual void start(bool bKeepAttr=false);
    virtual void abort();
    
    virtual bool step();

private:
    WaitAnim(long long duration, const boost::python::object& startCallback, 
            const boost::python::object& stopCallback);
    long long m_Duration;
    long long m_StartTime;
};

}

#endif

==> libavg_1.8.2.orig.tar.gz: libavg-1.8.2/src/anim/WaitAnim.h <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2014 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#ifndef _WaitAnim_H_
#define _WaitAnim_H_

#include "../api.h"

#include "SimpleAnim.h"

namespace avg {

class WaitAnim;
typedef boost::shared_ptr<class WaitAnim> WaitAnimPtr;

class AVG_API WaitAnim: public Anim {
public:
    WaitAnim(long long duration = -1,
            const boost::python::object& startCallback=boost::python::object(), 
            const boost::python::object& stopCallback=boost::python::object());
    virtual ~WaitAnim();
   
    virtual void start(bool bKeepAttr=false);
    virtual void abort();
    
    virtual bool step();

private:
    long long m_Duration;
    long long m_StartTime;
    WaitAnimPtr m_pThis; // Make sure we're not deleted while running.
};

}

#endif
